Module: wine
Branch: master
Commit: 413c6f60cf89cd04ecfde0b3f26f239129cb5b39
URL: http://source.winehq.org/git/wine.git/?a=commit;h=413c6f60cf89cd04ecfde0b3f…
Author: Francois Gouget <fgouget(a)free.fr>
Date: Wed Dec 2 01:42:31 2015 +0100
Assorted spelling fixes.
Signed-off-by: Francois Gouget <fgouget(a)free.fr>
Signed-off-by: Alexandre Julliard <julliard(a)winehq.org>
---
dlls/d3d10core/tests/device.c | 2 +-
dlls/d3d11/tests/d3d11.c | 2 +-
dlls/dsound/duplex.c | 2 +-
dlls/dxgi/tests/device.c | 2 +-
dlls/mshtml/htmlwindow.c | 2 +-
dlls/msrle32/tests/msrle.c | 2 +-
dlls/shell32/shfldr_unixfs.c | 2 +-
dlls/shell32/shlfileop.c | 2 +-
dlls/winepulse.drv/mmdevdrv.c | 10 +++++-----
dlls/winspool.drv/info.c | 2 +-
dlls/xaudio2_7/xaudio_dll.c | 2 +-
programs/cmd/tests/test_builtins.cmd | 2 +-
12 files changed, 16 insertions(+), 16 deletions(-)
diff --git a/dlls/d3d10core/tests/device.c b/dlls/d3d10core/tests/device.c
index d25600e..c13af50 100644
--- a/dlls/d3d10core/tests/device.c
+++ b/dlls/d3d10core/tests/device.c
@@ -1474,7 +1474,7 @@ static void test_create_sampler_state(void)
ok(d3d11_desc.Filter == expected_desc.Filter,
"Test %u: Got unexpected filter %#x.\n", i, d3d11_desc.Filter);
ok(d3d11_desc.AddressU == expected_desc.AddressU,
- "Test %u: Got unexpected adress u %u.\n", i, d3d11_desc.AddressU);
+ "Test %u: Got unexpected address u %u.\n", i, d3d11_desc.AddressU);
ok(d3d11_desc.AddressV == expected_desc.AddressV,
"Test %u: Got unexpected address v %u.\n", i, d3d11_desc.AddressV);
ok(d3d11_desc.AddressW == expected_desc.AddressW,
diff --git a/dlls/d3d11/tests/d3d11.c b/dlls/d3d11/tests/d3d11.c
index 7021c6f..6c8f0f7 100644
--- a/dlls/d3d11/tests/d3d11.c
+++ b/dlls/d3d11/tests/d3d11.c
@@ -1917,7 +1917,7 @@ static void test_create_sampler_state(void)
ok(d3d10_desc.Filter == expected_desc.Filter,
"Test %u: Got unexpected filter %#x.\n", i, d3d10_desc.Filter);
ok(d3d10_desc.AddressU == expected_desc.AddressU,
- "Test %u: Got unexpected adress u %u.\n", i, d3d10_desc.AddressU);
+ "Test %u: Got unexpected address u %u.\n", i, d3d10_desc.AddressU);
ok(d3d10_desc.AddressV == expected_desc.AddressV,
"Test %u: Got unexpected address v %u.\n", i, d3d10_desc.AddressV);
ok(d3d10_desc.AddressW == expected_desc.AddressW,
diff --git a/dlls/dsound/duplex.c b/dlls/dsound/duplex.c
index b18972e..153c7b6 100644
--- a/dlls/dsound/duplex.c
+++ b/dlls/dsound/duplex.c
@@ -67,7 +67,7 @@ static void fullduplex_destroy(IDirectSoundFullDuplexImpl *This)
}
/*******************************************************************************
- * IUnknown implemetation for DirectSoundFullDuplex
+ * IUnknown implementation for DirectSoundFullDuplex
*/
static inline IDirectSoundFullDuplexImpl *impl_from_IUnknown(IUnknown *iface)
{
diff --git a/dlls/dxgi/tests/device.c b/dlls/dxgi/tests/device.c
index 4e54f4f..dd5da83 100644
--- a/dlls/dxgi/tests/device.c
+++ b/dlls/dxgi/tests/device.c
@@ -1193,7 +1193,7 @@ static void test_swapchain_parameters(void)
/* Buffers > 0 are supposed to be read only. This is the case except that in
* fullscreen mode on Windows <= 8 the last backbuffer (BufferCount - 1) is
- * writeable. This is not the case if an unsupported refresh rate is passed
+ * writable. This is not the case if an unsupported refresh rate is passed
* for some reason, probably because the invalid refresh rate triggers a
* kinda-sorta windowed mode.
*
diff --git a/dlls/mshtml/htmlwindow.c b/dlls/mshtml/htmlwindow.c
index 5ed22c0..fbb558e 100644
--- a/dlls/mshtml/htmlwindow.c
+++ b/dlls/mshtml/htmlwindow.c
@@ -2653,7 +2653,7 @@ static HRESULT WINAPI WindowDispEx_InvokeEx(IDispatchEx *iface, DISPID id, LCID
DISPPARAMS dp = {args, NULL, 2, 0};
/*
- * setTimeout calls shoud use default value 0 for the second argument if only one is provided,
+ * setTimeout calls should use default value 0 for the second argument if only one is provided,
* but IDL file does not reflect that. We fixup arguments here instead.
*/
if(!(wFlags & DISPATCH_METHOD) || pdp->cArgs != 1 || pdp->cNamedArgs)
diff --git a/dlls/msrle32/tests/msrle.c b/dlls/msrle32/tests/msrle.c
index 38e74a6..14ddddb 100644
--- a/dlls/msrle32/tests/msrle.c
+++ b/dlls/msrle32/tests/msrle.c
@@ -137,7 +137,7 @@ static void test_raw_decompress(void)
hic = ICLocate(FCC('V', 'I', 'D', 'C'), codecs[i], bih, NULL, ICMODE_DECOMPRESS);
ok(hic != NULL, "Test[%d]: Expected non-NULL return\n", i);
- /* Now wich is this codec? Windows returns MRLE for uncompressed cases */
+ /* Now which is this codec? Windows returns MRLE for uncompressed cases */
memset(&codec_info, 0, sizeof(codec_info));
hr = ICGetInfo(hic, &codec_info, sizeof(codec_info));
ok(hr == sizeof(codec_info), "Test[%d]: Incorrect amount of data returned\n", i);
diff --git a/dlls/shell32/shfldr_unixfs.c b/dlls/shell32/shfldr_unixfs.c
index b3b0214..85383e8 100644
--- a/dlls/shell32/shfldr_unixfs.c
+++ b/dlls/shell32/shfldr_unixfs.c
@@ -776,7 +776,7 @@ static HRESULT UNIXFS_initialize_target_folder(UnixFolder *This, const char *szB
current = ILGetNext(current);
};
- /* Build the path and compute the attributes*/
+ /* Build the path and compute the attributes */
This->m_dwAttributes =
dwAttributes|SFGAO_FOLDER|SFGAO_HASSUBFOLDER|SFGAO_FILESYSANCESTOR|SFGAO_CANRENAME;
This->m_pszPath = pNextDir = SHAlloc(dwPathLen);
diff --git a/dlls/shell32/shlfileop.c b/dlls/shell32/shlfileop.c
index c843dd7..234a141 100644
--- a/dlls/shell32/shlfileop.c
+++ b/dlls/shell32/shlfileop.c
@@ -572,7 +572,7 @@ DWORD WINAPI Win32DeleteFileAW(LPCVOID path)
* dest [I] path to target file to move to
*
* RETURNS
- * ERORR_SUCCESS if successful
+ * ERROR_SUCCESS if successful
*/
static DWORD SHNotifyMoveFileW(LPCWSTR src, LPCWSTR dest)
{
diff --git a/dlls/winspool.drv/info.c b/dlls/winspool.drv/info.c
index ca2c34d..04def86 100644
--- a/dlls/winspool.drv/info.c
+++ b/dlls/winspool.drv/info.c
@@ -317,7 +317,7 @@ static const printenv_t * const all_printenv[] = {&env_x86, &env_x64, &env_win40
*
* NOTES
* An empty string is handled the same way as NULL.
- * SetLastEror(ERROR_INVALID_ENVIRONMENT) is called on Failure
+ * SetLastError(ERROR_INVALID_ENVIRONMENT) is called on Failure
*
*/
diff --git a/dlls/xaudio2_7/xaudio_dll.c b/dlls/xaudio2_7/xaudio_dll.c
index 73cf63d..04f975c 100644
--- a/dlls/xaudio2_7/xaudio_dll.c
+++ b/dlls/xaudio2_7/xaudio_dll.c
@@ -2091,7 +2091,7 @@ HRESULT WINAPI DllGetClassObject(REFCLSID rclsid, REFIID riid, void **ppv)
return IClassFactory_QueryInterface(factory, riid, ppv);
}
-/* returns TRUE if there is more data avilable in the buffer, FALSE if the
+/* returns TRUE if there is more data available in the buffer, FALSE if the
* buffer's data has all been queued */
static BOOL xa2buffer_queue_period(XA2SourceImpl *src, XA2Buffer *buf, ALuint al_buf)
{
diff --git a/programs/cmd/tests/test_builtins.cmd b/programs/cmd/tests/test_builtins.cmd
index 52c549e..cf2559a 100644
--- a/programs/cmd/tests/test_builtins.cmd
+++ b/programs/cmd/tests/test_builtins.cmd
@@ -973,7 +973,7 @@ del temp.bat 2>nul
goto :eof
:TestForR
-rem %CD% does not tork on NT4 so use the following workaround
+rem %CD% does not work on NT4 so use the following workaround
for /d %%i in (.) do set WINE_CURDIR=%%~dpnxi
echo --- for /R
diff --git a/dlls/winepulse.drv/mmdevdrv.c b/dlls/winepulse.drv/mmdevdrv.c
index 24972ab..0e6cf9f 100644
--- a/dlls/winepulse.drv/mmdevdrv.c
+++ b/dlls/winepulse.drv/mmdevdrv.c
@@ -506,7 +506,7 @@ fail:
return E_FAIL;
}
/* For default Pulseaudio render device, OR together all of the
* PKEY_AudioEndpoint_PhysicalSpeakers values of the sinks. */
static void pulse_phys_speakers_cb(pa_context *c, const pa_sink_info *i, int eol, void *userdata)
{
@@ -801,7 +801,7 @@ static HRESULT pulse_stream_connect(ACImpl *This, UINT32 period_bytes) {
pa_stream_set_buffer_attr_callback(This->stream, pulse_attr_update, This);
pa_stream_set_moved_callback(This->stream, pulse_attr_update, This);
/* Pulseaudio will fill in correct values */
attr.minreq = attr.fragsize = period_bytes;
attr.maxlength = attr.tlength = This->bufsize_bytes;
attr.prebuf = pa_frame_size(&This->ss);
@@ -2991,7 +2991,7 @@ static HRESULT WINAPI SimpleAudioVolume_SetMasterVolume(
if (context)
FIXME("Notifications not supported yet\n");
- TRACE("Pulseaudio does not support session volume control\n");
+ TRACE("PulseAudio does not support session volume control\n");
pthread_mutex_lock(&pulse_lock);
session->master_vol = level;
@@ -3127,7 +3127,7 @@ static HRESULT WINAPI ChannelAudioVolume_SetChannelVolume(
if (context)
FIXME("Notifications not supported yet\n");
- TRACE("Pulseaudio does not support session volume control\n");
+ TRACE("PulseAudio does not support session volume control\n");
pthread_mutex_lock(&pulse_lock);
session->channel_vols[index] = level;
@@ -3175,7 +3175,7 @@ static HRESULT WINAPI ChannelAudioVolume_SetAllVolumes(
if (context)
FIXME("Notifications not supported yet\n");
- TRACE("Pulseaudio does not support session volume control\n");
+ TRACE("PulseAudio does not support session volume control\n");
pthread_mutex_lock(&pulse_lock);
for(i = 0; i < count; ++i)
@@ -506,7 +506,7 @@ fail:
return E_FAIL;
}
-/* For default Pulseaudio render device, OR together all of the
+/* For default PulseAudio render device, OR together all of the
* PKEY_AudioEndpoint_PhysicalSpeakers values of the sinks. */
static void pulse_phys_speakers_cb(pa_context *c, const pa_sink_info *i, int eol, void *userdata)
@@ -801,7 +801,7 @@ static HRESULT pulse_stream_connect(ACImpl *This, UINT32 period_bytes) {
pa_stream_set_buffer_attr_callback(This->stream, pulse_attr_update, This);
pa_stream_set_moved_callback(This->stream, pulse_attr_update, This);
- /* Pulseaudio will fill in correct values */
+ /* PulseAudio will fill in correct values */
attr.minreq = attr.fragsize = period_bytes;
attr.maxlength = attr.tlength = This->bufsize_bytes;